audobject.resolver
==================

.. automodule:: audobject.resolver

Base
----

.. autoclass:: Base
    :members:

FilePath
--------

.. autoclass:: FilePath
    :members:

Function
--------

.. autoclass:: Function
    :members:

Tuple
-----

.. autoclass:: Tuple
    :members:

Type
----

.. autoclass:: Type
    :members:
